compute_va: Compute variability attribution

Description Usage Arguments Value

View source: R/compute_va.R

Description

This function uses the data structure prepared by the prepare functions and performs the actual variability attribution computation. The function will return a data frame that can be used to generate a plot.

Usage

1
2

Arguments

va_input

An input data structure as produced by the prepare_va_* functions

conditioning

A function or list determining in which order the computation should occur

idv

The independent variable column

facets

Columns to be used for facetting

Value

A data frame


sebastianueckert/vaplot documentation built on Sept. 1, 2021, 11:24 a.m.