Description Usage Arguments Value
This function uses the data structure prepared by the prepare functions and performs the actual variability attribution computation. The function will return a data frame that can be used to generate a plot.
1 2 | compute_va(va_input, conditioning = default_conditioning, idv = "TIME",
facets = NULL)
|
va_input |
An input data structure as produced by the prepare_va_* functions |
conditioning |
A function or list determining in which order the computation should occur |
idv |
The independent variable column |
facets |
Columns to be used for facetting |
A data frame
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.